@@ -1,7 +1,7 @@
 package App::GoogleAuthUtils;
 
-our $DATE = '2018-04-14'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2018-04-18'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -40,6 +40,10 @@ _
             schema => 'str*',
             pos => 2,
         },
+        output => {
+            schema => 'filename*',
+            cmdline_aliases => {o=>{}},
+        },
     },
     examples => [
         {
@@ -60,9 +64,12 @@ sub gen_google_auth_qrcode {
     my %args = @_;
 
     if (File::Which::which("qrencode")) {
+        my $output = $args{output} // '-';
+
         my $cmd = join(
             "",
-            "qrencode -o- -d 300 -s 10 ",
+            "qrencode -o ", String::ShellQuote::shell_quote($output),
+            " -d 300 -s 10 ",
             String::ShellQuote::shell_quote(
                 join(
                     "",
@@ -73,7 +80,11 @@ sub gen_google_auth_qrcode {
                 )
             ),
         );
-        system "$cmd | display";
+        if ($output eq '-') {
+            system "$cmd | display";
+        } else {
+            system $cmd;
+        }
     } else {
         my $url = join(
             '',
@@ -108,7 +119,7 @@ App::GoogleAuthUtils - Utilities related to Google Authenticator
 
 =head1 VERSION
 
-This document describes version 0.003 of App::GoogleAuthUtils (from Perl distribution App-GoogleAuthUtils), released on 2018-04-14.
+This document describes version 0.004 of App::GoogleAuthUtils (from Perl distribution App-GoogleAuthUtils), released on 2018-04-18.
 
 =head1 DESCRIPTION
 
@@ -164,6 +175,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<issuer>* => I<str>
 
+=item * B<output> => I<filename>
+
 =item * B<secret_key>* => I<str>
 
 =back
@@ -197,6 +210,8 @@ feature.
 
 =head1 SEE ALSO
 
+L<App::QRCodeUtils>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
